@@ -1,5 +1,14 @@
 var NAVTREEINDEX3 =
 {
+"class_pro_s_h_a_d_e__settings.html#afb183823a47a73d459a5bae16042bf4e":[2,0,6,116],
+"class_pro_s_h_a_d_e__settings.html#afb39c3bb75f1b925175f9f6b09ada148":[2,0,6,114],
+"class_pro_s_h_a_d_e__settings.html#afb42ec0cd0f8abb54327c0e2c3025ed1":[2,0,6,61],
+"class_pro_s_h_a_d_e__settings.html#afcece610f52c27cadefb217f1d0c278c":[2,0,6,92],
+"class_pro_s_h_a_d_e__settings.html#affb17d9099f0b85b3af04a78d5c670f4":[2,0,6,87],
+"classes.html":[2,1],
+"dir_031c4fc26031de218e3c67acfca35073.html":[3,0,0,0],
+"dir_5c0d64f70903e893b1efe571a4b8de29.html":[3,0,0,2],
+"dir_68267d1309a1af8e8297ef4c3efbcdba.html":[3,0,0],
 "dir_fa9be34cc2c3eb9c0decdfb277595ca7.html":[3,0,0,1],
 "files.html":[3,0],
 "functions.html":[2,3,0,0],
@@ -19,14 +28,13 @@ var NAVTREEINDEX3 =
 "functions_func_i.html":[2,3,1,6],
 "functions_func_m.html":[2,3,1,7],
 "functions_func_n.html":[2,3,1,8],
-"functions_func_o.html":[2,3,1,9],
-"functions_func_p.html":[2,3,1,10],
-"functions_func_r.html":[2,3,1,11],
-"functions_func_s.html":[2,3,1,12],
-"functions_func_t.html":[2,3,1,13],
-"functions_func_w.html":[2,3,1,14],
-"functions_func_z.html":[2,3,1,15],
-"functions_func_~.html":[2,3,1,16],
+"functions_func_p.html":[2,3,1,9],
+"functions_func_r.html":[2,3,1,10],
+"functions_func_s.html":[2,3,1,11],
+"functions_func_t.html":[2,3,1,12],
+"functions_func_w.html":[2,3,1,13],
+"functions_func_z.html":[2,3,1,14],
+"functions_func_~.html":[2,3,1,15],
 "functions_g.html":[2,3,0,6],
 "functions_h.html":[2,3,0,7],
 "functions_i.html":[2,3,0,8],
@@ -55,7 +63,7 @@ var NAVTREEINDEX3 =
 "index.html#firstModel":[0,4,2],
 "index.html#index":[0,2],
 "index.html#install":[0,3],
-"index.html#installBehaviour":[0,3,2],
+"index.html#installBehaviour":[0,3,3],
 "index.html#intro":[0,0],
 "index.html#libexamples":[0,6,1],
 "index.html#liblink":[0,6,0],
@@ -63,7 +71,7 @@ var NAVTREEINDEX3 =
 "index.html#otherDependencies":[0,3,1],
 "index.html#overlayExample":[0,5,3],
 "index.html#pdbInput":[0,4],
-"index.html#pipInstall":[0,3,3],
+"index.html#pipInstall":[0,3,4],
 "index.html#proshadeBinary":[0,5],
 "index.html#pyexamples":[0,7,0],
 "index.html#pyusage":[0,7],
@@ -72,13 +80,14 @@ var NAVTREEINDEX3 =
 "index.html#stdSys":[0,3,0],
 "index.html#symDetection":[0,5,0],
 "index.html#waterMols":[0,4,1],
-"namespace_pro_s_h_a_d_e__internal__data.html":[2,0,0],
+"index.html#winInstall":[0,3,2],
 "namespace_pro_s_h_a_d_e__internal__data.html":[1,0,0],
+"namespace_pro_s_h_a_d_e__internal__data.html":[2,0,0],
 "namespace_pro_s_h_a_d_e__internal__distances.html":[1,0,1],
 "namespace_pro_s_h_a_d_e__internal__io.html":[1,0,2],
 "namespace_pro_s_h_a_d_e__internal__map_manip.html":[1,0,3],
-"namespace_pro_s_h_a_d_e__internal__maths.html":[1,0,4],
 "namespace_pro_s_h_a_d_e__internal__maths.html":[2,0,1],
+"namespace_pro_s_h_a_d_e__internal__maths.html":[1,0,4],
 "namespace_pro_s_h_a_d_e__internal__messages.html":[1,0,5],
 "namespace_pro_s_h_a_d_e__internal__misc.html":[1,0,6],
 "namespace_pro_s_h_a_d_e__internal__overlay.html":[1,0,7],
